@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,19 +13,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
 import grpc  # type: ignore
 
 from google.cloud.webrisk_v1beta1.types import webrisk
-from .base import WebRiskServiceV1Beta1Transport, DEFAULT_CLIENT_INFO
+
+from .base import DEFAULT_CLIENT_INFO, WebRiskServiceV1Beta1Transport
 
 
 class WebRiskServiceV1Beta1GrpcTransport(WebRiskServiceV1Beta1Transport):
@@ -59,6 +58,7 @@ class WebRiskServiceV1Beta1GrpcTransport(WebRiskServiceV1Beta1Transport):
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -154,6 +154,7 @@ class WebRiskServiceV1Beta1GrpcTransport(WebRiskServiceV1Beta1Transport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -225,8 +226,7 @@ class WebRiskServiceV1Beta1GrpcTransport(WebRiskServiceV1Beta1Transport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -318,5 +318,9 @@ class WebRiskServiceV1Beta1GrpcTransport(WebRiskServiceV1Beta1Transport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("WebRiskServiceV1Beta1GrpcTransport",)
